@@ -13,6 +13,7 @@
 # limitations under the License.
 
 import copy
+from debtcollector import moves
 import logging
 
 import debtcollector
@@ -225,8 +226,8 @@ class CORS(base.ConfigurableMiddleware):
         # a string for allowed_origin instead of a list
         if isinstance(allowed_origin, six.string_types):
             # TODO(krotscheck): https://review.openstack.org/#/c/312687/
-            LOG.warn('DEPRECATED: The `allowed_origin` keyword argument in '
-                     '`add_origin()` should be a list, found String.')
+            LOG.warning('DEPRECATED: The `allowed_origin` keyword argument in '
+                        '`add_origin()` should be a list, found String.')
             allowed_origin = [allowed_origin]
 
         if allowed_origin:
@@ -245,6 +246,9 @@ class CORS(base.ConfigurableMiddleware):
                     'allow_headers': allow_headers
                 }
 
+    @moves.moved_method('set_defaults',
+                        message='CORS.set_latent has been deprecated in favor '
+                                'of oslo_middleware.cors.set_defaults')
     def set_latent(self, allow_headers=None, allow_methods=None,
                    expose_headers=None):
         '''Add a new latent property for this middleware.
